@@ -33,7 +33,6 @@
 #include <colord.h>
 #include <string.h>
 
-#include "cd-cleanup.h"
 #include "cd-compat-edid.h"
 
 /**
@@ -56,12 +55,12 @@ cd_edid_install_profile (unsigned char *edid,
 			 char *profile_fn)
 {
 	gboolean ret;
-	_cleanup_error_free_ GError *error = NULL;
-	_cleanup_free_ gchar *md5 = NULL;
-	_cleanup_object_unref_ CdClient *client = NULL;
-	_cleanup_object_unref_ CdDevice *device = NULL;
-	_cleanup_object_unref_ CdProfile *profile = NULL;
-	_cleanup_object_unref_ GFile *file = NULL;
+	g_autoptr(GError) error = NULL;
+	g_autofree gchar *md5 = NULL;
+	g_autoptr(CdClient) client = NULL;
+	g_autoptr(CdDevice) device = NULL;
+	g_autoptr(CdProfile) profile = NULL;
+	g_autoptr(GFile) file = NULL;
 
 	g_return_val_if_fail (profile_fn != NULL, CD_EDID_ERROR_RESOURCE);
 
@@ -192,12 +191,12 @@ cd_edid_remove_profile (unsigned char *edid,
 			char *profile_fn)
 {
 	gboolean ret;
-	_cleanup_error_free_ GError *error = NULL;
-	_cleanup_free_ gchar *md5 = NULL;
-	_cleanup_object_unref_ CdClient *client = NULL;
-	_cleanup_object_unref_ CdDevice *device = NULL;
-	_cleanup_object_unref_ CdProfile *profile = NULL;
-	_cleanup_object_unref_ GFile *file = NULL;
+	g_autoptr(GError) error = NULL;
+	g_autofree gchar *md5 = NULL;
+	g_autoptr(CdClient) client = NULL;
+	g_autoptr(CdDevice) device = NULL;
+	g_autoptr(CdProfile) profile = NULL;
+	g_autoptr(GFile) file = NULL;
 
 	g_return_val_if_fail (profile_fn != NULL, CD_EDID_ERROR_RESOURCE);
 
@@ -289,11 +288,11 @@ cd_edid_get_profile (unsigned char *edid,
 {
 	const gchar *filename;
 	gboolean ret;
-	_cleanup_error_free_ GError *error = NULL;
-	_cleanup_free_ gchar *md5 = NULL;
-	_cleanup_object_unref_ CdClient *client = NULL;
-	_cleanup_object_unref_ CdDevice *device = NULL;
-	_cleanup_object_unref_ CdProfile *profile = NULL;
+	g_autoptr(GError) error = NULL;
+	g_autofree gchar *md5 = NULL;
+	g_autoptr(CdClient) client = NULL;
+	g_autoptr(CdDevice) device = NULL;
+	g_autoptr(CdProfile) profile = NULL;
 
 	/* bad input */
 	if (edid == NULL || edid_len == 0)
