@@ -22,22 +22,16 @@
 #include "config.h"
 
 #include <string.h>
-
-#ifdef USE_POLKIT
 #include <polkit/polkit.h>
-#endif
 
 #include "cd-common.h"
 
-#if defined(USE_POLKIT) && !defined(POLKIT_HAS_AUTOPTR_MACROS)
+#if !defined(POLKIT_HAS_AUTOPTR_MACROS)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(PolkitAuthorizationResult, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(PolkitSubject, g_object_unref)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(PolkitAuthority, g_object_unref)
 #endif
 
-/**
- * cd_client_error_quark:
- **/
 GQuark
 cd_client_error_quark (void)
 {
@@ -54,9 +48,6 @@ cd_client_error_quark (void)
 	return quark;
 }
 
-/**
- * cd_main_ensure_dbus_path:
- **/
 gchar *
 cd_main_ensure_dbus_path (const gchar *object_path)
 {
@@ -70,9 +61,6 @@ cd_main_ensure_dbus_path (const gchar *object_path)
 	return object_path_tmp;
 }
 
-/**
- * cd_main_get_sender_uid:
- **/
 guint
 cd_main_get_sender_uid (GDBusConnection *connection,
 			const gchar *sender,
@@ -99,9 +87,6 @@ cd_main_get_sender_uid (GDBusConnection *connection,
 	return uid;
 }
 
-/**
- * cd_main_get_sender_pid:
- **/
 guint
 cd_main_get_sender_pid (GDBusConnection *connection,
 			const gchar *sender,
@@ -128,9 +113,6 @@ cd_main_get_sender_pid (GDBusConnection *connection,
 	return pid;
 }
 
-/**
- * cd_main_sender_authenticated:
- **/
 gboolean
 cd_main_sender_authenticated (GDBusConnection *connection,
 			      const gchar *sender,
@@ -139,11 +121,9 @@ cd_main_sender_authenticated (GDBusConnection *connection,
 {
 	guint uid;
 	g_autoptr(GError) error_local = NULL;
-#ifdef USE_POLKIT
 	g_autoptr(PolkitAuthority) authority = NULL;
 	g_autoptr(PolkitAuthorizationResult) result = NULL;
 	g_autoptr(PolkitSubject) subject = NULL;
-#endif
 
 	/* uid 0 is allowed to do all actions */
 	uid = cd_main_get_sender_uid (connection, sender, &error_local);
@@ -173,7 +153,6 @@ cd_main_sender_authenticated (GDBusConnection *connection,
 	}
 #endif
 
-#ifdef USE_POLKIT
 	/* get authority */
 	authority = polkit_authority_get_sync (NULL, &error_local);
 	if (authority == NULL) {
@@ -212,17 +191,10 @@ cd_main_sender_authenticated (GDBusConnection *connection,
 			     action_id);
 		return FALSE;
 	}
-#else
-	g_warning ("CdCommon: not checking %s for %s as no PolicyKit support",
-		   action_id, sender);
-#endif
 	return TRUE;
 }
 
 
-/**
- * cd_main_mkdir_with_parents:
- **/
 gboolean
 cd_main_mkdir_with_parents (const gchar *filename, GError **error)
 {
